@@ -14,9 +14,10 @@ class pdfConfig(ConfigElement):
     pdfConfig(default="allow", embedded_images="sanitise")
     """
 
-    def __init__(self, default: str = "sanitise", **kwargs):
+    def __init__(self, default: str = "sanitise", attributes: dict = {}, **kwargs):
         self.name = self.__class__.__name__
         self.default = default
+        self.attributes = attributes
         self.switches_module = switches.pdf
         self.default_switches = [
             self.switches_module.acroform(value=default),
@@ -33,6 +34,7 @@ class pdfConfig(ConfigElement):
         super().__init__(
             name=self.name,
             default=self.default,
+            attributes=self.attributes,
             switches_module=self.switches_module,
             default_switches=self.default_switches,
             config=kwargs
