@@ -10,12 +10,12 @@ class Rebuild(Policy):
     def __init__(self, default: str = "sanitise", config: dict = {}):
         self.default = default
         self.default_config_elements = [
-            glasswall.content_management.config_elements.pdfConfig,
-            glasswall.content_management.config_elements.pptConfig,
-            glasswall.content_management.config_elements.sysConfig,
-            glasswall.content_management.config_elements.tiffConfig,
-            glasswall.content_management.config_elements.wordConfig,
-            glasswall.content_management.config_elements.xlsConfig,
+            glasswall.content_management.config_elements.pdfConfig(default=default),
+            glasswall.content_management.config_elements.pptConfig(default=default),
+            glasswall.content_management.config_elements.sysConfig(),
+            glasswall.content_management.config_elements.tiffConfig(default=default),
+            glasswall.content_management.config_elements.wordConfig(default=default),
+            glasswall.content_management.config_elements.xlsConfig(default=default),
         ]
         self.config = config or {}
 
